# mautrix-facebook
A Matrix-Facebook Messenger puppeting bridge.

### [Wiki](https://github.com/tulir/mautrix-facebook/wiki)

### [Features & Roadmap](https://github.com/tulir/mautrix-facebook/blob/master/ROADMAP.md)

## Discussion
Matrix room: [`#facebook:maunium.net`](https://matrix.to/#/#facebook:maunium.net)
